require 'json'
require 'pathname'

# README
remove_file "README.rdoc"
create_file "README.md", "##{app_name}\n\nTODO: Write an awesome README\n"

# Rbenv-Vars
create_file ".rbenv-vars.example", "PRODUCTION_DATABASE_PASSWORD=\n"
run "cp .rbenv-vars.example .rbenv-vars"

append_to_file '.gitignore', ".rbenv-vars\n"

# Ruby Version
create_file ".ruby-version", "2.1.2"

# Gems
gem 'active_model_serializers'
gem 'responders'

gem_group :development, :test do
  gem 'rspec-rails'
  gem 'factory_girl_rails'
  gem 'pry-byebug'
  gem 'zeus'
  gem 'guard-rspec', require: false
  gem 'pry-rails'
  gem 'faker'
  gem 'shoulda-matchers', require: false
  gem 'rspec-nc', require: false
  gem 'rspec-legacy_formatters', require: false
end

here_gemfile = Pathname.new(Dir.pwd).join('Gemfile')

run "BUNDLE_GEMFILE=#{here_gemfile} bundle install"

# RSpec
run "BUNDLE_GEMFILE=#{here_gemfile} bundle exec rails g rspec:install"
comment_lines 'spec/spec_helper.rb', "require 'rspec/autorun'"
inject_into_file 'spec/spec_helper.rb', "\n  config.include FactoryGirl::Syntax::Methods\n", after: "config.order = \"random\"\n"
prepend_to_file 'spec/spec_helper.rb', "require 'rspec'\n"

# Zeus
run "BUNDLE_GEMFILE=#{here_gemfile} bundle exec zeus init"

## zeus.json
zeus_json = JSON.parse(File.read('zeus.json'))
zeus_json['plan']['boot']['default_bundle']['test_environment']['prerake_test'] = begin
  {'rake:test' => []}
end
gsub_file 'zeus.json', /^[\w\W]*$/, JSON.pretty_generate(zeus_json)

## custom_plan.rb
gsub_file 'custom_plan.rb', /class CustomPlan[\w\W]+end/ do
<<-RUBY
class CustomPlan < Zeus::Rails
  def prerake_test
    require 'rake'
  end

  define_method "rake:test" do
    Rake.application.run
  end
end
RUBY
end

# Guard
run "BUNDLE_GEMFILE=#{here_gemfile} bundle exec guard init rspec"
gsub_file 'Guardfile', 'guard :rspec do', "guard :rspec, cmd: 'zeus rspec' do"

# API
run "BUNDLE_GEMFILE=#{here_gemfile} bundle exec rails g responders:install"

remove_file "config/locales/responders.en.yml"
gsub_file "lib/application_responder.rb", "  include Responders::HttpCacheResponder\n", ""
gsub_file "app/controllers/application_controller.rb", "respond_to :html", "respond_to :json"

# Database
gsub_file "config/database.yml", "#{app_name.upcase}_DATABASE_PASSWORD", "PRODUCTION_DATABASE_PASSWORD"

run "BUNDLE_GEMFILE=#{here_gemfile} bundle exec rake db:create"
run "RAILS_ENV=test BUNDLE_GEMFILE=#{here_gemfile} bundle exec rake db:create"
